summaryrefslogtreecommitdiffstats
path: root/src/H5Spublic.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Spublic.h')
-rw-r--r--src/H5Spublic.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/H5Spublic.h b/src/H5Spublic.h
index afbb32b..3f57139 100644
--- a/src/H5Spublic.h
+++ b/src/H5Spublic.h
@@ -39,12 +39,12 @@ typedef enum H5S_class_t {
typedef enum H5S_seloper_t {
H5S_SELECT_NOOP = -1, /* error */
H5S_SELECT_SET = 0, /* Select "set" operation */
- H5S_SELECT_OR, /* Binary "or" operation (add new selection
- * to existing selection)
- */
- H5S_SELECT_INVALID /* Invalid upper bound on selection
- * operations
- */
+ H5S_SELECT_OR, /* Binary "or" operation for hyperslabs
+ * (add new selection to existing selection)
+ */
+ H5S_SELECT_APPEND, /* Append elements to end of point selection */
+ H5S_SELECT_PREPEND, /* Prepend elements to beginning of point selection */
+ H5S_SELECT_INVALID /* Invalid upper bound on selection operations */
} H5S_seloper_t;
#ifdef __cplusplus